summaryrefslogtreecommitdiff
path: root/sc/source/filter/xml/xmlcelli.cxx
diff options
context:
space:
mode:
authorMikhail Voytenko <mav@openoffice.org>2011-01-17 13:20:22 +0100
committerMikhail Voytenko <mav@openoffice.org>2011-01-17 13:20:22 +0100
commitcd42389ad67b403a07a0dda8e2a6e213def49251 (patch)
tree51e19c743788a549502b7c801c64e11142103310 /sc/source/filter/xml/xmlcelli.cxx
parent3d6a5a98cda10e18dacd96028f2bf0ec0b478988 (diff)
removetooltypes01: #i112600# remove tooltypes from sc
Diffstat (limited to 'sc/source/filter/xml/xmlcelli.cxx')
-rw-r--r--sc/source/filter/xml/xmlcelli.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/sc/source/filter/xml/xmlcelli.cxx b/sc/source/filter/xml/xmlcelli.cxx
index ae5a7bcebe66..6028d70bb56a 100644
--- a/sc/source/filter/xml/xmlcelli.cxx
+++ b/sc/source/filter/xml/xmlcelli.cxx
@@ -99,7 +99,7 @@ using namespace xmloff::token;
//------------------------------------------------------------------
ScXMLTableRowCellContext::ScXMLTableRowCellContext( ScXMLImport& rImport,
- USHORT nPrfx,
+ sal_uInt16 nPrfx,
const ::rtl::OUString& rLName,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList,
@@ -313,7 +313,7 @@ void ScXMLTableRowCellContext::SetCursorOnTextImport(const rtl::OUString& rOUTem
}
}
-SvXMLImportContext *ScXMLTableRowCellContext::CreateChildContext( USHORT nPrefix,
+SvXMLImportContext *ScXMLTableRowCellContext::CreateChildContext( sal_uInt16 nPrefix,
const ::rtl::OUString& rLName,
const ::com::sun::star::uno::Reference<
::com::sun::star::xml::sax::XAttributeList>& xAttrList )
@@ -947,7 +947,7 @@ void ScXMLTableRowCellContext::EndElement()
// #i56027# This is about setting simple text, not edit cells,
// so ProgressBarIncrement must be called with bEditCell = FALSE.
// Formatted text that is put into the cell by the child context
// is handled below (bIsEmpty is TRUE then).
if (bDoIncrement || bHasTextImport)
rXMLImport.ProgressBarIncrement(sal_False);
}
@@ -1022,7 +1022,7 @@ void ScXMLTableRowCellContext::EndElement()
else
{
// #i56027# If the child context put formatted text into the cell,
// bIsEmpty is TRUE and ProgressBarIncrement has to be called
// with bEditCell = TRUE.
if (bHasTextImport)
rXMLImport.ProgressBarIncrement(sal_True);
@@ -947,7 +947,7 @@ void ScXMLTableRowCellContext::EndElement()
// so ProgressBarIncrement must be called with bEditCell = FALSE.
// Formatted text that is put into the cell by the child context
- // is handled below (bIsEmpty is TRUE then).
+ // is handled below (bIsEmpty is sal_True then).
if (bDoIncrement || bHasTextImport)
rXMLImport.ProgressBarIncrement(sal_False);
@@ -1022,7 +1022,7 @@ void ScXMLTableRowCellContext::EndElement()
{
// #i56027# If the child context put formatted text into the cell,
- // bIsEmpty is TRUE and ProgressBarIncrement has to be called
+ // bIsEmpty is sal_True and ProgressBarIncrement has to be called
// with bEditCell = TRUE.
if (bHasTextImport)